@@ -3,8 +3,42 @@ Contains some fields as utilities
 """
 from django import forms
 from django.conf import settings
+from django.forms.util import flatatt
+from django.utils.encoding import force_unicode
 from django.utils.safestring import mark_safe
 
+class NullCheckboxWidget(forms.CheckboxInput):
+    
+    def render(self, name, value, attrs=None):
+        final_attrs = self.build_attrs(attrs, type='checkbox', name=name)
+        try:
+            result = self.check_test(value)
+        except: # Silently catch exceptions
+            result = False
+        if result:
+            final_attrs['checked'] = 'checked'
+        if not (value is True or value is False or value is None or value == ''):
+            # Only add the 'value' attribute if a value is non-empty.
+            final_attrs['value'] = force_unicode(value)
+        return mark_safe(u'<input%s />' % flatatt(final_attrs))
+
+    def value_from_datadict(self, data, files, name):
+        if name not in data:
+            # A missing value means False because HTML form submission does not
+            # send results for unselected checkboxes.
+            return False
+        value = data.get(name)
+        # Translate true and false strings to boolean values.
+        values =  {'on': True, 'false': False}
+        if isinstance(value, basestring):
+            value = values.get(value.lower(), value)
+        return value
+
+    def _has_changed(self, initial, data):
+        # Sometimes data or initial could be None or u'' which should be the
+        # same thing as False.
+        return bool(initial) != bool(data)
+
 class SubFKWidget(forms.Select):
     """
     This widget creates a formfield for a foreignkey but linked to its subclasses.
